@@ -113,11 +113,14 @@ _TESTED_OS_VERSIONS = [
     ("11", "4"),
     ("11", "5"),
     ("11", "6"),
+    ("11", "7"),
     ("12", "0"),
     ("12", "1"),
     ("12", "2"),
     ("12", "3"),
     ("12", "4"),
+    ("12", "5"),
+    ("12", "6"),
 ]
 
 # Photos 5 has persons who are empty string if unidentified face
@@ -260,10 +263,9 @@ EXTENDED_ATTRIBUTE_NAMES = [
     "description",
     "findercomment",
     "headline",
-    "keywords",
     "participants",
     "projects",
-    "rating",
+    "starrating",
     "subject",
     "title",
     "version",
