@@ -35,6 +35,7 @@ __all__ = [
     "DB_OPTION",
     "DEBUG_OPTIONS",
     "DELETED_OPTIONS",
+    "FIELD_OPTION",
     "JSON_OPTION",
     "QUERY_OPTIONS",
     "THEME_OPTION",
@@ -116,6 +117,19 @@ JSON_OPTION = click.option(
     help="Print output in JSON format.",
 )
 
+FIELD_OPTION = click.option(
+    "--field",
+    "-f",
+    metavar="FIELD TEMPLATE",
+    multiple=True,
+    nargs=2,
+    help="Output only specified custom fields. "
+    "FIELD is the name of the field and TEMPLATE is the template to use as the field value. "
+    "May be repeated to output multiple fields. "
+    "For example, to output photo uuid, name, and title: "
+    '`--field uuid "{uuid}" --field name "{original_name}" --field title "{title}"`.',
+)
+
 
 def DELETED_OPTIONS(f):
     o = click.option
@@ -420,6 +434,12 @@ def QUERY_OPTIONS(f):
             is_flag=True,
             help="Search for photos that were imported as referenced files (not copied into Photos library).",
         ),
+        o(
+            "--not-reference",
+            is_flag=True,
+            help="Search for photos that are not references, that is, they were copied into the Photos library "
+            "and are managed by Photos.",
+        ),
         o(
             "--in-album",
             is_flag=True,
