@@ -52,9 +52,16 @@ def trim(text: str, pad: str = "") -> str:
     return text if len(text) <= width else f"{text[: width- 3]}..."
 
 
-def inspect_photo(photo: PhotoInfo, detected_text: Optional[str] = None) -> str:
+def inspect_photo(
+    photo: PhotoInfo,
+    detected_text: Optional[str] = None,
+    templates: Optional[List[str]] = None,
+) -> str:
     """Get info about an osxphotos PhotoInfo object formatted for printing"""
 
+    if templates:
+        return inspect_photo_templates(photo, templates)
+
     properties = [
         bold("Filename: ") + f"[filename]{photo.original_filename}[/]",
         bold("Type: ") + get_photo_type(photo),
@@ -78,14 +85,32 @@ def inspect_photo(photo: PhotoInfo, detected_text: Optional[str] = None) -> str:
             + f"[time]{photo.import_info.creation_date.isoformat()}[/]"
         )
 
+    file_size = (
+        bold("File size: ")
+        + f"[num]{float(bitmath.Byte(photo.original_filesize).to_MB()):.2f} MB[/]"
+    )
+
+    if photo.live_photo and photo.path_live_photo:
+        file_size += (
+            " | [num]"
+            + f"{float(bitmath.Byte(pathlib.Path(photo.path_live_photo).stat().st_size).to_MB()):.2f}"
+            + " MB (Live video)[/]"
+        )
+
+    if photo.has_raw and photo.path_raw:
+        file_size += (
+            " | [num]"
+            + f"{float(bitmath.Byte(pathlib.Path(photo.path_raw).stat().st_size).to_MB()):.2f}"
+            + " MB (RAW photo)[/]"
+        )
+
     properties.extend(
         [
             bold("Dimensions: ")
             + f"[num]{photo.width}[/] x [num]{photo.height}[/] "
             + bold("Orientation: ")
             + f"[num]{photo.orientation}[/]",
-            bold("File size: ")
-            + f"[num]{float(bitmath.Byte(photo.original_filesize).to_MB()):.2f} MB[/]",
+            file_size,
             bold("Title: ") + f"{photo.title or '-'}",
             bold("Description: ")
             + f"{trim(photo.description or '-', 'Description: ')}",
@@ -99,7 +124,7 @@ def inspect_photo(photo: PhotoInfo, detected_text: Optional[str] = None) -> str:
             bold("Location: ")
             + f"{', '.join(dd_to_dms_str(*photo.location)) if photo.location[0] else '-'}",
             bold("Place: ") + f"{photo.place.name if photo.place else '-'}",
-            bold("Categories: ") + f"{', '.join(photo.labels) or '-'}",
+            bold("Categories/Labels: ") + f"{', '.join(photo.labels) or '-'}",
         ]
     )
     properties.append(format_flags(photo))
@@ -140,6 +165,30 @@ def inspect_photo(photo: PhotoInfo, detected_text: Optional[str] = None) -> str:
     return "\n".join(properties)
 
 
+def inspect_photo_templates(
+    photo: PhotoInfo, templates: Optional[List[str]] = None
+) -> str:
+    """Render and display photo templates"""
+    properties = [
+        bold("Filename: ") + f"[filename]{photo.original_filename}[/]",
+        bold("Type: ") + get_photo_type(photo),
+        bold("UUID: ") + f"[uuid]{photo.uuid}[/]",
+    ]
+    properties.append(bold("Templates: "))
+    properties.append(format_templates(photo, templates))
+
+    return "\n".join(properties)
+
+
+def format_templates(photo: PhotoInfo, templates: List[str]) -> str:
+    """Format templates for a photo"""
+    formatted_templates = []
+    for template in templates:
+        template_str, _ = photo.render_template(template)
+        formatted_templates.append((template, template_str))
+    return "\n".join(f"{t[0]} = {t[1]}" for t in formatted_templates)
+
+
 def format_score_info(photo: PhotoInfo) -> str:
     """Format score_info"""
     score_str = bold("Score: ")
@@ -200,6 +249,10 @@ def format_paths(photo: PhotoInfo) -> str:
         path_str += "\n"
         path_str += bold("Path edited: ")
         path_str += f"[filepath]{format_path_link(photo.path_edited)}[/]"
+    if photo.path_live_photo:
+        path_str += "\n"
+        path_str += bold("Path live video: ")
+        path_str += f"[filepath]{format_path_link(photo.path_live_photo)}[/]"
     if photo.path_raw:
         path_str += "\n"
         path_str += bold("Path raw: ")
@@ -339,9 +392,18 @@ def make_layout() -> Layout:
 
 @click.command(name="inspect")
 @click.option("--detect-text", "-t", is_flag=True, help="Detect text in photos")
+@click.option(
+    "--template",
+    "-T",
+    metavar="TEMPLATE",
+    multiple=True,
+    help="Template string to render for each photo using template preview mode. "
+    "Useful for testing templates for export; may be repeated to test multiple templates. "
+    "If --template/-T is used, other inspection data will not be displayed. ",
+)
 @THEME_OPTION
 @DB_OPTION
-def photo_inspect(db, theme, detect_text):
+def photo_inspect(db, theme, detect_text, template):
     """Interactively inspect photos selected in Photos.
 
     Open Photos then run `osxphotos inspect` in the terminal.
@@ -375,7 +437,7 @@ def photo_inspect(db, theme, detect_text):
         if uuid == CURRENT_UUID:
             layout["main"].update(
                 Panel(
-                    inspect_photo(photo, text),
+                    inspect_photo(photo, detected_text=text),
                     title=photo.title or photo.original_filename,
                 )
             )
@@ -414,14 +476,16 @@ def photo_inspect(db, theme, detect_text):
                                 inspect_photo(
                                     photo,
                                     detected_text=detected_text_cache.get(uuid, None),
+                                    templates=template,
                                 ),
                                 title=photo.title or photo.original_filename,
                             )
                         )
 
-                        # start text detection if requested
+                        # start text detection if requested (but not if in template preview mode)
                         if (
                             detect_text
+                            and not template
                             and photo.isphoto
                             and (
                                 photo.path
