@@ -3,16 +3,24 @@
 import click
 
 import osxphotos
+from osxphotos.cli.click_rich_echo import (
+    rich_click_echo,
+    set_rich_console,
+    set_rich_theme,
+)
 from osxphotos.debug import set_debug
 from osxphotos.photosalbum import PhotosAlbum
+from osxphotos.phototemplate import RenderOptions
 from osxphotos.queryoptions import QueryOptions
 
+from .color_themes import get_default_theme
 from .common import (
     CLI_COLOR_ERROR,
     CLI_COLOR_WARNING,
     DB_ARGUMENT,
     DB_OPTION,
     DELETED_OPTIONS,
+    FIELD_OPTION,
     JSON_OPTION,
     OSXPHOTOS_HIDDEN,
     QUERY_OPTIONS,
@@ -20,7 +28,8 @@ from .common import (
     load_uuid_from_file,
 )
 from .list import _list_libraries
-from .print_photo_info import print_photo_info
+from .print_photo_info import print_photo_fields, print_photo_info
+from .verbose import get_verbose_console
 
 
 @click.command()
@@ -62,6 +71,24 @@ from .print_photo_info import print_photo_info
     "This only works if the Photos library being queried is the last-opened (default) library in Photos. "
     "This feature is currently experimental.  I don't know how well it will work on large query sets.",
 )
+@click.option(
+    "--quiet",
+    is_flag=True,
+    help="Quiet output; doesn't actually print query results. "
+    "Useful with --print and --add-to-album if you don't want to see the actual query results.",
+)
+@FIELD_OPTION
+@click.option(
+    "--print",
+    "print_template",
+    metavar="TEMPLATE",
+    multiple=True,
+    help="Render TEMPLATE string for each photo queried and print to stdout. "
+    "TEMPLATE is an osxphotos template string. "
+    "This may be useful for creating custom reports, etc. "
+    "Most useful with --quiet. "
+    "May be repeated to print multiple template strings. ",
+)
 @click.option(
     "--debug", required=False, is_flag=True, default=False, hidden=OSXPHOTOS_HIDDEN
 )
@@ -88,6 +115,7 @@ def query(
     exif,
     external_edit,
     favorite,
+    field,
     folder,
     from_date,
     from_time,
@@ -127,6 +155,7 @@ def query(
     not_missing,
     not_panorama,
     not_portrait,
+    not_reference,
     not_screenshot,
     not_selfie,
     not_shared,
@@ -138,8 +167,10 @@ def query(
     person,
     place,
     portrait,
+    print_template,
     query_eval,
     query_function,
+    quiet,
     regex,
     screenshot,
     selected,
@@ -176,7 +207,6 @@ def query(
         from_date,
         from_time,
         has_raw,
-        is_reference,
         keyword,
         label,
         max_size,
@@ -220,6 +250,7 @@ def query(
         (shared, not_shared),
         (slow_mo, not_slow_mo),
         (time_lapse, not_time_lapse),
+        (is_reference, not_reference),
     ]
     # print help if no non-exclusive term or a double exclusive term is given
     if any(all(bb) for bb in exclusive) or not any(
@@ -229,6 +260,10 @@ def query(
         click.echo(ctx.obj.group.commands["query"].get_help(ctx), err=True)
         return
 
+    # set console for rich_echo to be same as for verbose_
+    set_rich_console(get_verbose_console())
+    set_rich_theme(get_default_theme())
+
     # actually have something to query
     # default searches for everything
     photos = True
@@ -309,6 +344,7 @@ def query(
         not_missing=not_missing,
         not_panorama=not_panorama,
         not_portrait=not_portrait,
+        not_reference=not_reference,
         not_screenshot=not_screenshot,
         not_selfie=not_selfie,
         not_shared=not_shared,
@@ -366,4 +402,25 @@ def query(
                 err=True,
             )
 
-    print_photo_info(photos, cli_json or json_, print_func=click.echo)
+    if field:
+        print_photo_fields(photos, field, cli_json or json_)
+
+    if print_template:
+        options = RenderOptions()
+        for p in photos:
+            for template in print_template:
+                rendered_templates, unmatched = p.render_template(
+                    template,
+                    options,
+                )
+                if unmatched:
+                    rich_click_echo(
+                        f"[warning]Unmatched template field: {unmatched}[/]"
+                    )
+                for rendered_template in rendered_templates:
+                    if not rendered_template:
+                        continue
+                    print(rendered_template)
+
+    if not quiet and not field:
+        print_photo_info(photos, cli_json or json_, print_func=click.echo)
